@@ -1,4 +1,4 @@
-__all__ = ["LocalizedString"]
+__all__ = ["LocaleUtils", "LocalizedString"]
 
 from typing import Any, List, Optional
 
@@ -6,9 +6,21 @@ from java.lang import Object, String
 from java.util import Locale
 
 
+class LocaleUtils(Object):
+    @staticmethod
+    def getAvailableLocales(andRegionalVariants):
+        # type: (bool) -> List[Locale]
+        pass
+
+    @staticmethod
+    def parseLocale(locale):
+        # type: (String) -> Optional[Locale]
+        pass
+
+
 class LocalizedString(Object):
     def __init__(self, *args):
-        # type: (Any) -> None
+        # type: (*Any) -> None
         pass
 
     def compareTo(self, other):
