@@ -7,7 +7,7 @@ __all__ = [
 ]
 
 from com.palantir.ptoss.cinch.core import DefaultBindableModel
-from java.lang import Object, String
+from java.lang import String
 from java.util import Date
 
 
@@ -228,7 +228,7 @@ class ScheduleAdjustment(DefaultBindableModel):
 
     def contains(self, timestamp):
         # type: (long) -> bool
-        pass
+        return True
 
     def getEnd(self):
         # type: () -> Date
