@@ -27,13 +27,13 @@ __all__ = [
 
 from typing import Any, Optional, Union
 
+from dev.thecesrom.helper.types import AnyStr
 from java.lang import (
     Appendable,
     AutoCloseable,
     CharSequence,
     Exception,
     Object,
-    String,
     Throwable,
 )
 
@@ -51,14 +51,15 @@ class Flushable(object):
 
 
 class File(Object):
-    pathSeparator = None  # type: String
-    pathSeparatorChar = None  # type: String
-    separator = None  # type: String
-    separatorChar = None  # type: String
+    pathSeparator = None  # type: AnyStr
+    pathSeparatorChar = None  # type: AnyStr
+    separator = None  # type: AnyStr
+    separatorChar = None  # type: AnyStr
 
     def __init__(self, *args):
         # type: (*Any) -> None
-        pass
+        super(File, self).__init__()
+        print(args)
 
 
 class FileDescriptor(Object):
@@ -68,7 +69,7 @@ class FileDescriptor(Object):
 
     def valid(self):
         # type: () -> bool
-        pass
+        return True
 
 
 class OutputStream(Object, Closeable, Flushable):
@@ -93,7 +94,8 @@ class OutputStream(Object, Closeable, Flushable):
 class FileOutputStream(OutputStream):
     def __init__(self, *args):
         # type: (*Any) -> None
-        pass
+        super(FileOutputStream, self).__init__()
+        print(args)
 
     def getChannel(self):
         # type: () -> Any
@@ -109,6 +111,7 @@ class FilterOutputStream(OutputStream):
 
     def __init__(self, out):
         # type: (OutputStream) -> None
+        super(FilterOutputStream, self).__init__()
         self._out = out
 
 
@@ -133,7 +136,7 @@ class DataOutputStream(FilterOutputStream):
         pass
 
     def writeBytes(self, s):
-        # type: (String) -> None
+        # type: (AnyStr) -> None
         pass
 
     def writeChar(self, v):
@@ -141,7 +144,7 @@ class DataOutputStream(FilterOutputStream):
         pass
 
     def writeChars(self, s):
-        # type: (String) -> None
+        # type: (AnyStr) -> None
         pass
 
     def writeDouble(self, v):
@@ -165,7 +168,7 @@ class DataOutputStream(FilterOutputStream):
         pass
 
     def writeUTF(self, s):
-        # type: (String) -> None
+        # type: (AnyStr) -> None
         pass
 
 
@@ -183,7 +186,7 @@ class PrintStream(FilterOutputStream):
 
     def checkError(self):
         # type: () -> bool
-        pass
+        return True
 
     def format(self, *args):
         # type: (*Any) -> PrintStream
@@ -217,7 +220,7 @@ class InputStream(Object, Closeable):
 
     def markSupported(self):
         # type: () -> bool
-        pass
+        return True
 
     @staticmethod
     def nullInputStream():
@@ -266,7 +269,7 @@ class Reader(Object, AutoCloseable):
 
     def markSupported(self):
         # type: () -> bool
-        pass
+        return True
 
     @staticmethod
     def nullReader():
@@ -279,7 +282,7 @@ class Reader(Object, AutoCloseable):
 
     def ready(self):
         # type: () -> bool
-        pass
+        return True
 
     def reset(self):
         # type: () -> None
@@ -297,6 +300,7 @@ class Reader(Object, AutoCloseable):
 class BufferedReader(Reader):
     def __init__(self, in_, sz=None):
         # type: (Reader, Optional[int]) -> None
+        super(BufferedReader, self).__init__()
         print(in_, sz)
 
     def close(self):
@@ -330,13 +334,15 @@ class Writer(Object, Appendable, Closeable, Flushable):
 class BufferedWriter(Writer):
     def __init__(self, out, sz=None):
         # type: (Writer, Optional[int]) -> None
+        super(BufferedWriter, self).__init__()
         print(out, sz)
 
 
 class PrintWriter(Writer):
     def __init__(self, *args):
         # type: (*Any) -> None
-        pass
+        super(PrintWriter, self).__init__()
+        print(args)
 
     def append(self, c_csq, start=0, end=-1):
         # type: (Union[CharSequence, str], int, int) -> PrintWriter
@@ -344,7 +350,7 @@ class PrintWriter(Writer):
 
     def checkError(self):
         # type: () -> bool
-        pass
+        return True
 
     def format(self, *args):
         # type: (*Any) -> PrintWriter
