@@ -27,7 +27,6 @@ __all__ = [
 
 import __builtin__ as builtins
 import time
-
 from typing import Any, List, Optional, TypeVar, Union
 
 String = Union[str, unicode]
@@ -43,23 +42,23 @@ class Object(object):
 
     def __cmp__(self, other):
         # type: (Object) -> bool
-        pass
+        return True
 
     def __ge__(self, other):
         # type: (Object) -> bool
-        pass
+        return True
 
     def __gt__(self, other):
         # type: (Object) -> bool
-        pass
+        return True
 
     def __lt__(self, other):
         # type: (Object) -> bool
-        pass
+        return True
 
     def equals(self, obj):
         # type: (Object) -> bool
-        pass
+        return True
 
     def getClass(self):
         # type: () -> Class
@@ -103,10 +102,10 @@ class CharSequence(object):
         # type: (int) -> str
         raise NotImplementedError
 
-    def chars(self):
+    def chars(self):  # type: ignore[no-untyped-def]
         pass
 
-    def codePoints(self):
+    def codePoints(self):  # type: ignore[no-untyped-def]
         pass
 
     @staticmethod
@@ -227,7 +226,7 @@ class StackTraceElement(Object):
 
     def isNativeMethod(self):
         # type: () -> bool
-        pass
+        return True
 
 
 class StringBuffer(Object, CharSequence):
