@@ -11,7 +11,8 @@ __all__ = [
 
 from typing import List, TypeVar
 
-from java.lang import Enum, Object, String
+from dev.thecesrom.helper.types import AnyStr
+from java.lang import Enum, Object
 from java.security import Principal
 from java.time import Instant
 from java.util.concurrent import TimeUnit
@@ -21,7 +22,7 @@ T = TypeVar("T")
 
 class AttributeView(object):
     def name(self):
-        # type: () -> String
+        # type: () -> AnyStr
         raise NotImplementedError
 
 
@@ -65,7 +66,7 @@ class BasicFileAttributes(object):
 
 class FileAttribute(object):
     def name(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def value(self):
@@ -75,7 +76,7 @@ class FileAttribute(object):
 
 class FileAttributeView(AttributeView):
     def name(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
 
@@ -125,7 +126,7 @@ class UserPrincipal(Principal):
         return True
 
     def getName(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def hashCode(self):
@@ -133,11 +134,11 @@ class UserPrincipal(Principal):
         pass
 
     def toString(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
 
 class FileStoreAttributeView(AttributeView):
     def name(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
