@@ -7,6 +7,7 @@ bit array).
 from __future__ import print_function
 
 __all__ = [
+    "Arrays",
     "Calendar",
     "Collection",
     "Comparator",
@@ -21,10 +22,11 @@ __all__ = [
     "UUID",
 ]
 
-from typing import Any, Dict, List, Optional, Set, TypeVar, Union
+from typing import Any, Dict, Iterable, List, Optional, Set, TypeVar, Union
 
+from dev.thecesrom.helper.types import AnyStr
 from dev.thecesrom.utils.decorators import classproperty
-from java.lang import Object, String
+from java.lang import Class, Object
 from java.time import Instant, ZoneId
 from java.util.function import (
     Consumer,
@@ -329,6 +331,103 @@ class Stream(object):
             raise NotImplementedError
 
 
+class Arrays(object):
+    @staticmethod
+    def asList(a):
+        # type: (Any) -> List[Any]
+        pass
+
+    @staticmethod
+    def binarySearch(*args, **kwargs):
+        # type: (*Any, **Any) -> int
+        pass
+
+    @staticmethod
+    def compare(*args, **kwargs):
+        # type: (*Any, **Any) -> int
+        pass
+
+    @staticmethod
+    def compareUnsigned(*args, **kwargs):
+        # type: (*Any, **Any) -> int
+        pass
+
+    @staticmethod
+    def copyOf(original, newLength, newType=None):
+        # type: (List[Any], int, Optional[Class]) -> List[Any]
+        pass
+
+    @staticmethod
+    def copyOfRange(original, from_, to, newType=None):
+        # type: (List[Any], int, int, Optional[Class]) -> List[Any]
+        pass
+
+    @staticmethod
+    def deepEquals(a1, a2):
+        # type: (List[Object], List[Object]) -> bool
+        pass
+
+    @staticmethod
+    def equals(*args, **kwargs):
+        # type: (*Any, **Any) -> bool
+        pass
+
+    @staticmethod
+    def fill(a, *args):
+        # type: (List[Any], *Any) -> None
+        pass
+
+    @staticmethod
+    def hashCode(a):
+        # type: (Iterable) -> int
+        pass
+
+    @staticmethod
+    def mismatch(*args, **kwargs):
+        # type: (*Any, **Any) -> int
+        pass
+
+    @staticmethod
+    def parallelPrefix(*args, **kwargs):
+        # type: (*Any, **Any) -> None
+        pass
+
+    @staticmethod
+    def parallelSetAll(*args, **kwargs):
+        # type: (*Any, **Any) -> None
+        pass
+
+    @staticmethod
+    def parallelSort(*args, **kwargs):
+        # type: (*Any, **Any) -> None
+        pass
+
+    @staticmethod
+    def setAll(*args, **kwargs):
+        # type: (*Any, **Any) -> None
+        pass
+
+    @staticmethod
+    def sort(*args, **kwargs):
+        # type: (*Any, **Any) -> None
+        pass
+
+    @staticmethod
+    def spliterator(array, startInclusive=None, endExclusive=None):
+        # type: (Iterable, Optional[int], Optional[int]) -> Spliterator
+        pass
+
+    @staticmethod
+    def stream(array, startInclusive=None, endExclusive=None):
+        # type: (Iterable, Optional[int], Optional[int]) -> Stream
+        pass
+
+    @staticmethod
+    def toString(a):
+        # type: (Iterable) -> AnyStr
+        pass
+
+
 class Calendar(Object):
     ALL_STYLES = None  # type: int
     AM = None  # type: int
@@ -419,7 +518,7 @@ class Calendar(Object):
 
     @staticmethod
     def getAvailableCalendarTypes():
-        # type: () -> Set[String]
+        # type: () -> Set[AnyStr]
         pass
 
     @staticmethod
@@ -428,15 +527,15 @@ class Calendar(Object):
         pass
 
     def getCalendarType(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def getDisplayName(self, field, style, locale):
-        # type: (int, int, Locale) -> String
+        # type: (int, int, Locale) -> AnyStr
         pass
 
     def getDisplayNames(self, field, style, locale):
-        # type: (int, int, Locale) -> Dict[String, int]
+        # type: (int, int, Locale) -> Dict[AnyStr, int]
         pass
 
     def getFirstDayOfWeek(self):
@@ -523,16 +622,16 @@ class Currency(Object):
         pass
 
     def getCurrencyCode(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def getDisplayName(self, locale=None):
-        # type: (Optional[Locale]) -> String
+        # type: (Optional[Locale]) -> AnyStr
         pass
 
     @staticmethod
     def getInstance(arg):
-        # type: (Union[Locale, String]) -> Currency
+        # type: (Union[Locale, AnyStr]) -> Currency
         pass
 
     def getNumericCode(self):
@@ -540,11 +639,11 @@ class Currency(Object):
         pass
 
     def getNumericCodeAsString(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def getSymbol(self, locale=None):
-        # type: (Optional[Locale]) -> String
+        # type: (Optional[Locale]) -> AnyStr
         pass
 
 
@@ -555,6 +654,7 @@ class Date(Object):
 
     def __init__(self, date=None):
         # type: (Optional[long]) -> None
+        super(Date, self).__init__()
         print(self, date)
 
     def after(self, when):
@@ -591,6 +691,7 @@ class EventObject(Object):
 
     def __init__(self, source):
         # type: (Object) -> None
+        super(EventObject, self).__init__()
         self._source = source
 
     def getSource(self):
@@ -614,6 +715,7 @@ class Locale(Object):
 
     def __init__(self, language, country=None, variant=None):
         # type: (str, Optional[str], Optional[str]) -> None
+        super(Locale, self).__init__()
         self.language = language
         self.country = country
         self.variant = variant
@@ -745,7 +847,7 @@ class TimeZone(Object):
 
     @staticmethod
     def getAvailableIDs(rawOffset=None):
-        # type: (Optional[int]) -> List[String]
+        # type: (Optional[int]) -> List[AnyStr]
         pass
 
     @staticmethod
@@ -754,7 +856,7 @@ class TimeZone(Object):
         pass
 
     def getDisplayName(self, *args):
-        # type: (*Any) -> String
+        # type: (*Any) -> AnyStr
         pass
 
     def getDSTSavings(self):
@@ -762,7 +864,7 @@ class TimeZone(Object):
         pass
 
     def getID(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def getOffset(self, *args):
@@ -775,7 +877,7 @@ class TimeZone(Object):
 
     @staticmethod
     def getTimeZone(arg):
-        # type: (Union[String, ZoneId]) -> TimeZone
+        # type: (Union[AnyStr, ZoneId]) -> TimeZone
         pass
 
     def hasSameRules(self, other):
@@ -796,7 +898,7 @@ class TimeZone(Object):
         pass
 
     def setID(self, ID):
-        # type: (String) -> None
+        # type: (AnyStr) -> None
         pass
 
     def setRawOffset(self, offsetMillis):
@@ -815,6 +917,7 @@ class TimeZone(Object):
 class UUID(Object):
     def __init__(self, mostSigBits, leastSigBits):
         # type: (long, long) -> None
+        super(UUID, self).__init__()
         self._leastSigbits = leastSigBits
         self._mostSigBits = mostSigBits
 
@@ -828,7 +931,7 @@ class UUID(Object):
 
     @staticmethod
     def fromString(name):
-        # type: (String) -> UUID
+        # type: (AnyStr) -> UUID
         pass
 
     def getLeastSignificantBits(self):
