@@ -10,14 +10,17 @@ __all__ = [
     "JLayeredPane",
     "JOptionPane",
     "JPanel",
+    "JPasswordField",
     "JPopupMenu",
     "JTextField",
 ]
 
+import array
+import warnings
 from typing import Any, List, Optional
 
+from dev.thecesrom.helper.types import AnyStr
 from java.awt import Component, Container, Frame, Graphics
-from java.lang import String
 from java.util import Locale
 from javax.swing.event import AncestorListener
 from javax.swing.plaf import DesktopPaneUI
@@ -101,7 +104,7 @@ class Icon(object):
 
 
 class JComponent(Container):
-    TOOL_TIP_TEXT_KEY = None  # type: String
+    TOOL_TIP_TEXT_KEY = None  # type: AnyStr
     UNDEFINED_CONDITION = None  # type: int
     WHEN_ANCESTOR_OF_FOCUSED_COMPONENT = None  # type: int
     WHEN_FOCUSED = None  # type: int
@@ -109,7 +112,7 @@ class JComponent(Container):
 
     def __init__(self):
         # type: () -> None
-        pass
+        super(JComponent, self).__init__()
 
     def addAncestorListener(self, listener):
         # type: (AncestorListener) -> None
@@ -148,7 +151,7 @@ class JFrame(Frame):
 class JInternalFrame(JComponent):
     def __init__(
         self,
-        title=None,  # type: Optional[String]
+        title=None,  # type: Optional[AnyStr]
         resizable=None,  # type: Optional[bool]
         closable=None,  # type: Optional[bool]
         maximizable=None,  # type: Optional[bool]
@@ -235,7 +238,7 @@ class JDesktopPane(JLayeredPane):
         pass
 
     def getUIClassID(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def updateUI(self):
@@ -275,7 +278,7 @@ class JOptionPane(JComponent):
     def showConfirmDialog(
         parentComponent,  # type: Optional[Any]
         message,  # type: Any
-        title=None,  # type: Optional[String]
+        title=None,  # type: Optional[AnyStr]
         optionType=None,  # type: Optional[int]
         messageType=None,  # type: Optional[int]
         icon=None,  # type: Optional[Icon]
@@ -288,13 +291,13 @@ class JOptionPane(JComponent):
     def showInputDialog(
         parentComponent,  # type: Optional[Any]
         message,  # type: Any
-        title=None,  # type: Optional[String]
+        title=None,  # type: Optional[AnyStr]
         messageType=None,  # type: Optional[int]
         icon=None,  # type: Optional[Icon]
         selectionValues=None,  # type: Optional[List[Any]]
         initialSelectionValue=None,  # type: Optional[Any]
     ):
-        # type: (...) -> String
+        # type: (...) -> AnyStr
         print(
             parentComponent,
             message,
@@ -310,7 +313,7 @@ class JOptionPane(JComponent):
     def showMessageDialog(
         parentComponent,  # type: Optional[Any]
         message,  # type: Any
-        title=None,  # type: Optional[String]
+        title=None,  # type: Optional[AnyStr]
         messageType=None,  # type: Optional[int]
         icon=None,  # type: Optional[Icon]
     ):
@@ -321,7 +324,7 @@ class JOptionPane(JComponent):
     def showOptionDialog(
         parentComponent,  # type: Optional[Any]
         message,  # type: Any
-        title=None,  # type: Optional[String]
+        title=None,  # type: Optional[AnyStr]
         optionType=None,  # type: Optional[int]
         messageType=None,  # type: Optional[int]
         icon=None,  # type: Optional[Icon]
@@ -359,7 +362,7 @@ class JToolTip(JComponent):
         pass
 
     def getTipText(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
 
@@ -374,7 +377,7 @@ class JPopupMenu(JComponent):
     """
 
     def __init__(self, label=None):
-        # type: (Optional[String]) -> None
+        # type: (Optional[AnyStr]) -> None
         super(JPopupMenu, self).__init__()
         print(label)
 
@@ -386,4 +389,50 @@ class JTextField(JTextComponent):
 
     def __init__(self, *args):
         # type: (*Any) -> None
+        super(JTextField, self).__init__()
+
+
+class JPasswordField(JTextField):
+    def __init__(self, *args):
+        # type: (*Any) -> None
+        super(JPasswordField, self).__init__(*args)
+
+    def copy(self):
+        # type: () -> None
+        pass
+
+    def cut(self):
+        # type: () -> None
+        pass
+
+    def echoCharIsSet(self):
+        # type: () -> bool
+        pass
+
+    def getEchoChar(self):
+        # type: () -> AnyStr
+        pass
+
+    def getPassword(self):
+        # type: () -> Any
+        return array.array("c", "password")
+
+    def getText(self, *args):
+        # type: (*int) -> unicode
+        warnings.warn(
+            "As of Java 2 platform v1.2, replaced by getPassword.",
+            DeprecationWarning,
+        )
+        return unicode("password")
+
+    def getUIClassID(self):
+        # type: () -> AnyStr
+        pass
+
+    def setEchoChar(self, c):
+        # type: (AnyStr) -> None
+        pass
+
+    def updateUI(self):
+        # type: () -> None
         pass
