@@ -14,19 +14,27 @@ __all__ = [
     "PyException",
     "PyFrame",
     "PyFunction",
+    "PyInteger",
+    "PyList",
     "PyMethodDescr",
     "PyNewWrapper",
     "PyObject",
+    "PySequence",
+    "PySequenceList",
+    "PyString",
     "PyStringMap",
     "PyTraceback",
+    "PyTuple",
     "PyType",
     "TraceFunction",
     "Visitproc",
 ]
 
-from enum import Enum
 from typing import Any, Iterable, Iterator, List, Optional, Tuple, Union
 
+from enum import Enum
+
+import java.util
 from java.io import PrintWriter
 from java.lang import Class, Object, RuntimeException, String, StringBuilder, Throwable
 from org.python.expose import TypeBuilder
@@ -37,6 +45,7 @@ class PyObject(Object):
     an instance of the class PyObject or one of its subclasses.
     """
 
+    gcMonitorGlobal = None  # type: bool
     TYPE = None  # type: PyType
 
     def __init__(self, objtype=None):
@@ -73,7 +82,7 @@ class PyObject(Object):
 
     def __contains__(self, o):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def __delete__(self, obj):
         # type: (PyObject) -> None
@@ -204,10 +213,11 @@ class PyObject(Object):
         pass
 
     def __iter__(self):
-        # type: () -> Iterator[PyObject]
+        # type: () -> Iterator[Any]
         pass
 
     def __iternext__(self):
+        # type: () -> PyObject
         pass
 
     def __itruediv__(self, other):
@@ -612,15 +622,15 @@ class PyObject(Object):
 
     def implementsDescrDelete(self):
         # type: () -> bool
-        pass
+        return True
 
     def implementsDescrGet(self):
         # type: () -> bool
-        pass
+        return True
 
     def implementsDescrSet(self):
         # type: () -> bool
-        pass
+        return True
 
     def invoke(self, *args, **kwargs):
         # type: (*Any, **Any) -> PyObject
@@ -628,31 +638,31 @@ class PyObject(Object):
 
     def isCallable(self):
         # type: () -> bool
-        pass
+        return True
 
     def isDataDescr(self):
         # type: () -> bool
-        pass
+        return True
 
     def isIndex(self):
         # type: () -> bool
-        pass
+        return True
 
     def isInteger(self):
         # type: () -> bool
-        pass
+        return True
 
     def isMappingType(self):
         # type: () -> bool
-        pass
+        return True
 
     def isNumberType(self):
         # type: () -> bool
-        pass
+        return True
 
     def isSequenceType(self):
         # type: () -> bool
-        pass
+        return True
 
     def noAttributeError(self, name):
         # type: (String) -> None
@@ -693,7 +703,7 @@ class CodeFlag(Enum):
 
     def isFlagBitSetIn(self, flags):
         # type: (int) -> bool
-        pass
+        return True
 
     @staticmethod
     def valueOf(name):
@@ -730,7 +740,7 @@ class CompilerFlags(Object):
 
     def isFlagSet(self, flag):
         # type: (CodeFlag) -> bool
-        pass
+        return True
 
     def toBits(self):
         # type: () -> int
@@ -764,7 +774,7 @@ class PyBaseCode(PyCode):
 
     def hasFreevars(self):
         # type: () -> bool
-        pass
+        return True
 
 
 class PyBuiltinCallable(PyObject):
@@ -825,7 +835,7 @@ class PyBuiltinMethod(PyBuiltinCallable):
 
     def refersDirectlyTo(self, ob):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def traverse(self, visit, arg):
         # type: (Visitproc, Object) -> int
@@ -845,7 +855,7 @@ class PyCell(PyObject):
 
     def refersDirectlyTo(self, ob):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def traverse(self, visit, arg):
         # type: (Visitproc, Object) -> int
@@ -880,7 +890,7 @@ class PyDescriptor(PyObject, PyBuiltinCallable.Info):
 
     def refersDirectlyTo(self, ob):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def traverse(self, visit, arg):
         # type: (Visitproc, Object) -> int
@@ -919,11 +929,11 @@ class PyException(RuntimeException):
 
     def isExceptionClass(self, obj):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def match(self, exc):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def normalize(self):
         # type: () -> None
@@ -931,7 +941,7 @@ class PyException(RuntimeException):
 
     def refersDirectlyTo(self, ob):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def super__printStackTrace(self, w):
         # type: (PrintWriter) -> None
@@ -1025,7 +1035,7 @@ class PyFrame(PyObject):
 
     def refersDirectlyTo(self, ob):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def setderef(self, index, value):
         # type: (int, PyObject) -> None
@@ -1058,12 +1068,21 @@ class PyFrame(PyObject):
 
 class PyFunction(PyObject):
     def __init__(self, *args):
+        # type: (*Any) -> None
         print(args)
         super(PyFunction, self).__init__()
 
 
+class PyInteger(PyObject):
+    def __init__(self, *args):
+        # type: (*Any) -> None
+        print(args)
+        super(PyInteger, self).__init__()
+
+
 class PyMethodDescr(PyDescriptor):
     def __init__(self, t, func):
+        # type: (PyType, PyBuiltinCallable) -> None
         super(PyMethodDescr, self).__init__(t, func)
 
 
@@ -1088,6 +1107,243 @@ class PyNewWrapper(PyBuiltinMethod):
         pass
 
 
+class PySequence(PyObject):
+    pass
+
+
+class PySequenceList(PySequence):
+    def add(self, *args):
+        # type: (*Any) -> Optional[bool]
+        raise NotImplementedError
+
+    def addAll(self, *args):
+        # type: (*Any) -> bool
+        raise NotImplementedError
+
+    def clear(self):
+        # type: () -> None
+        raise NotImplementedError
+
+    def contains(self, o):
+        # type: (Object) -> bool
+        raise NotImplementedError
+
+    def containsAll(self, c):
+        # type: (java.util.Collection) -> bool
+        raise NotImplementedError
+
+    def get(self, index):
+        # type: (int) -> Object
+        raise NotImplementedError
+
+    def getArray(self):
+        # type: () -> List[PyObject]
+        raise NotImplementedError
+
+    def indexOf(self, o):
+        # type: (Object) -> int
+        raise NotImplementedError
+
+    def isEmpty(self):
+        # type: () -> bool
+        raise NotImplementedError
+
+    def iterator(self):
+        # type: () -> java.util.Iterator
+        raise NotImplementedError
+
+    def lastIndexOf(self, o):
+        # type: (Object) -> int
+        raise NotImplementedError
+
+    def listIterator(self, index=None):
+        # type: (Optional[int]) -> java.util.ListIterator
+        raise NotImplementedError
+
+    def pyadd(self, *args):
+        # type: (*Any) -> Optional[bool]
+        raise NotImplementedError
+
+    def pyget(self, index):
+        # type: (int) -> PyObject
+        raise NotImplementedError
+
+    def pyset(self, index, element):
+        # type: (int, PyObject) -> None
+        raise NotImplementedError
+
+    def refersDirectlyTo(self, ob):
+        # type: (PyObject) -> bool
+        return True
+
+    def remove(self, *args):
+        # type: (*Any) -> Union[bool, None, Object]
+        raise NotImplementedError
+
+    def removeAll(self, c):
+        # type: (java.util.Collection) -> bool
+        raise NotImplementedError
+
+    def retainAll(self, c):
+        # type: (java.util.Collection) -> bool
+        raise NotImplementedError
+
+    def set(self, index, element):
+        # type: (int, Object) -> Object
+        raise NotImplementedError
+
+    def size(self):
+        # type: () -> int
+        raise NotImplementedError
+
+    def subList(self, fromIndex, toIndex):
+        # type: (int, int) -> List[PyObject]
+        raise NotImplementedError
+
+    def toArray(self, a=None):
+        # type: (Optional[List[Object]]) -> List[Object]
+        raise NotImplementedError
+
+    def traverse(self, visit, arg):
+        # type: (Visitproc, Object) -> int
+        pass
+
+
+class PyList(PySequenceList):
+    def __init__(self, *args):
+        # type: (*Any) -> None
+        print(args)
+        super(PyList, self).__init__()
+
+    def add(self, *args):
+        # type: (*Any) -> Optional[bool]
+        pass
+
+    def addAll(self, *args):
+        # type: (*Any) -> bool
+        return True
+
+    def append(self, o):
+        # type: (PyObject) -> None
+        pass
+
+    def clear(self):
+        # type: () -> None
+        pass
+
+    def contains(self, o):
+        # type: (Object) -> bool
+        return True
+
+    def containsAll(self, c):
+        # type: (java.util.Collection) -> bool
+        return True
+
+    def count(self, o):
+        # type: (PyObject) -> int
+        pass
+
+    def extend(self, o):
+        # type: (PyObject) -> None
+        pass
+
+    @staticmethod
+    def fromList(list_):
+        # type: (List[PyObject]) -> PyList
+        pass
+
+    def get(self, index):
+        # type: (int) -> Object
+        pass
+
+    def getArray(self):
+        # type: () -> List[PyObject]
+        pass
+
+    def index(self, o, *args):
+        # type: (PyObject, *int) -> int
+        pass
+
+    def indexOf(self, o):
+        # type: (Object) -> int
+        pass
+
+    def insert(self, o):
+        # type: (PyObject) -> None
+        pass
+
+    def isEmpty(self):
+        # type: () -> bool
+        return True
+
+    def iterator(self):
+        # type: () -> java.util.Iterator
+        pass
+
+    def lastIndexOf(self, o):
+        # type: (Object) -> int
+        pass
+
+    def listIterator(self, index=None):
+        # type: (Optional[int]) -> java.util.ListIterator
+        pass
+
+    def pyadd(self, *args):
+        # type: (*Any) -> Optional[bool]
+        pass
+
+    def pyget(self, index):
+        # type: (int) -> PyObject
+        pass
+
+    def pyset(self, index, element):
+        # type: (int, PyObject) -> None
+        pass
+
+    def remove(self, *args):
+        # type: (*Any) -> Union[bool, None, Object]
+        pass
+
+    def removeAll(self, c):
+        # type: (java.util.Collection) -> bool
+        return True
+
+    def retainAll(self, c):
+        # type: (java.util.Collection) -> bool
+        return True
+
+    def reverse(self):
+        # type: () -> None
+        pass
+
+    def set(self, index, element):
+        # type: (int, Object) -> Object
+        pass
+
+    def size(self):
+        # type: () -> int
+        pass
+
+    def sort(self, *args):
+        # type: (*PyObject) -> None
+        pass
+
+    def subList(self, fromIndex, toIndex):
+        # type: (int, int) -> List[PyObject]
+        pass
+
+    def toArray(self, a=None):
+        # type: (Optional[List[Object]]) -> List[Object]
+        pass
+
+
+class PyString(PyObject):
+    def __init__(self, *args):
+        # type: (*Any) -> None
+        print(args)
+        super(PyString, self).__init__()
+
+
 class PyTraceback(PyObject):
     tb_frame = None  # type: PyFrame
     tb_lineno = None  # type: int
@@ -1104,13 +1360,125 @@ class PyTraceback(PyObject):
 
     def refersDirectlyTo(self, ob):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def traverse(self, visit, arg):
         # type: (Visitproc, Object) -> int
         pass
 
 
+class PyTuple(PySequenceList):
+    def __init__(self, *args):
+        # type: (*Any) -> None
+        print(args)
+        super(PyTuple, self).__init__()
+
+    def add(self, *args):
+        # type: (*Any) -> Optional[bool]
+        pass
+
+    def addAll(self, *args):
+        # type: (*Any) -> bool
+        return True
+
+    def clear(self):
+        # type: () -> None
+        pass
+
+    def contains(self, o):
+        # type: (Object) -> bool
+        return True
+
+    def containsAll(self, c):
+        # type: (java.util.Collection) -> bool
+        return True
+
+    def count(self, value):
+        # type: (PyObject) -> int
+        pass
+
+    @staticmethod
+    def fromIterable(iterable):
+        # type: (PyObject) -> PyTuple
+        pass
+
+    def get(self, index):
+        # type: (int) -> Object
+        pass
+
+    def getArray(self):
+        # type: () -> List[PyObject]
+        pass
+
+    def index(self, value, *args):
+        # type: (PyObject, *int) -> int
+        pass
+
+    def indexOf(self, o):
+        # type: (Object) -> int
+        pass
+
+    def isEmpty(self):
+        # type: () -> bool
+        return True
+
+    def iterator(self):
+        # type: () -> java.util.Iterator
+        pass
+
+    def lastIndexOf(self, o):
+        # type: (Object) -> int
+        pass
+
+    def listIterator(self, index=None):
+        # type: (Optional[int]) -> java.util.ListIterator
+        pass
+
+    def pyadd(self, *args):
+        # type: (*Any) -> Optional[bool]
+        pass
+
+    def pyget(self, index):
+        # type: (int) -> PyObject
+        pass
+
+    def pyset(self, index, element):
+        # type: (int, PyObject) -> None
+        pass
+
+    def remove(self, *args):
+        # type: (*Any) -> Union[bool, None, Object]
+        pass
+
+    def removeAll(self, c):
+        # type: (java.util.Collection) -> bool
+        return True
+
+    def retainAll(self, c):
+        # type: (java.util.Collection) -> bool
+        return True
+
+    def set(self, index, element):
+        # type: (int, Object) -> Object
+        pass
+
+    def size(self):
+        # type: () -> int
+        pass
+
+    def subList(self, fromIndex, toIndex):
+        # type: (int, int) -> List[PyObject]
+        pass
+
+    def toArray(self, a=None):
+        # type: (Optional[List[Object]]) -> List[Object]
+        pass
+
+    def tuple___iter__(self):
+        # type: () -> PyObject
+        pass
+
+
 class PyType(PyObject):
     @staticmethod
     def addBuilder(c, builder):
@@ -1136,7 +1504,7 @@ class PyType(PyObject):
     @staticmethod
     def ensureBootstrapped():
         # type: () -> bool
-        pass
+        return True
 
     @staticmethod
     def ensureDoc(arg):
@@ -1207,7 +1575,7 @@ class PyType(PyObject):
 
     def isSubType(self, supertype):
         # type: (PyType) -> bool
-        pass
+        return True
 
     def lookup_where(self, name, where):
         # type: (String, List[PyObject]) -> PyObject
@@ -1219,7 +1587,7 @@ class PyType(PyObject):
 
     def needsFinalizer(self):
         # type: () -> bool
-        pass
+        return True
 
     @staticmethod
     def newType(
@@ -1246,7 +1614,7 @@ class PyType(PyObject):
 
     def refersDirectlyTo(self, ob):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def removeMethod(self, meth):
         # type: (PyBuiltinMethod) -> None
@@ -1286,7 +1654,7 @@ class PyType(PyObject):
 
     def type___instancecheck__(self, inst):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def type___le__(self, other):
         # type: (PyObject) -> PyObject
@@ -1302,7 +1670,7 @@ class PyType(PyObject):
 
     def type___subclasscheck__(self, inst):
         # type: (PyObject) -> bool
-        pass
+        return True
 
     def type___subclasses__(self):
         # type: () -> PyObject
