@@ -23,12 +23,12 @@ from typing import Any, Dict, List, Optional, Tuple, Union
 
 from com.inductiveautomation.ignition.common.alarming.evaluation import ShelvedPath
 from com.inductiveautomation.ignition.common.alarming.query import AlarmQueryResultImpl
-from java.lang import String
+from dev.thecesrom.helper.types import AnyStr
 from java.util import Date
 
 
 def acknowledge(alarmIds, notes, username=None):
-    # type: (List[String], String, Optional[String]) -> None
+    # type: (List[AnyStr], AnyStr, Optional[AnyStr]) -> None
     """Acknowledges any number of alarms, specified by their event ids.
 
     The event id is generated for an alarm when it becomes active, and
@@ -53,7 +53,7 @@ def acknowledge(alarmIds, notes, username=None):
 
 
 def cancel(alarmIds):
-    # type: (List[String]) -> None
+    # type: (List[AnyStr]) -> None
     """Cancels any number of alarms, specified by their event ids.
 
     Event ids can be obtained from the system.alarm.queryStatus
@@ -68,7 +68,7 @@ def cancel(alarmIds):
 
 
 def createRoster(name, description):
-    # type: (String, String) -> None
+    # type: (AnyStr, AnyStr) -> None
     """This function creates a new roster.
 
     Users may be added to the roster through the Gateway or the Roster
@@ -83,7 +83,7 @@ def createRoster(name, description):
 
 
 def getRosters():
-    # type: () -> Dict[String, List[String]]
+    # type: () -> Dict[AnyStr, List[AnyStr]]
     """This function returns a mapping of roster names to a list of
     usernames contained in the roster.
 
@@ -107,7 +107,7 @@ def getShelvedPaths():
 
 
 def listPipelines(projectName="alarm-pipelines"):
-    # type: (String) -> List[String]
+    # type: (AnyStr) -> List[AnyStr]
     """Will return a list of the available Alarm Notification Pipelines.
 
     Args:
@@ -126,15 +126,15 @@ def listPipelines(projectName="alarm-pipelines"):
 def queryJournal(
     startDate=None,  # type: Optional[Date]
     endDate=None,  # type: Optional[Date]
-    journalName=None,  # type: Optional[String]
-    priority=None,  # type: Optional[List[Union[String, int]]]
-    state=None,  # type: Optional[List[Union[String, int]]]
-    path=None,  # type: Optional[List[String]]
-    source=None,  # type: Optional[List[String]]
-    displaypath=None,  # type: Optional[List[String]]
-    all_properties=None,  # type: Optional[List[Tuple[String, String, Any]]]
-    any_properties=None,  # type: Optional[List[Tuple[String, String, Any]]]
-    defined=None,  # type: Optional[List[String]]
+    journalName=None,  # type: Optional[AnyStr]
+    priority=None,  # type: Optional[List[Union[AnyStr, int]]]
+    state=None,  # type: Optional[List[Union[AnyStr, int]]]
+    path=None,  # type: Optional[List[AnyStr]]
+    source=None,  # type: Optional[List[AnyStr]]
+    displaypath=None,  # type: Optional[List[AnyStr]]
+    all_properties=None,  # type: Optional[List[Tuple[AnyStr, AnyStr, Any]]]
+    any_properties=None,  # type: Optional[List[Tuple[AnyStr, AnyStr, Any]]]
+    defined=None,  # type: Optional[List[AnyStr]]
     includeData=None,  # type: Optional[bool]
     includeSystem=None,  # type: Optional[bool]
     isSystem=None,  # type: Optional[bool]
@@ -221,14 +221,14 @@ def queryJournal(
 
 
 def queryStatus(
-    priority=None,  # type: Optional[List[Union[String, int]]]
-    state=None,  # type: Optional[List[Union[String, int]]]
-    path=None,  # type: Optional[List[String]]
-    source=None,  # type: Optional[List[String]]
-    displaypath=None,  # type: Optional[List[String]]
-    all_properties=None,  # type: Optional[List[Tuple[String, String, Any]]]
-    any_properties=None,  # type: Optional[List[Tuple[String, String, Any]]]
-    defined=None,  # type: Optional[List[String]]
+    priority=None,  # type: Optional[List[Union[AnyStr, int]]]
+    state=None,  # type: Optional[List[Union[AnyStr, int]]]
+    path=None,  # type: Optional[List[AnyStr]]
+    source=None,  # type: Optional[List[AnyStr]]
+    displaypath=None,  # type: Optional[List[AnyStr]]
+    all_properties=None,  # type: Optional[List[Tuple[AnyStr, AnyStr, Any]]]
+    any_properties=None,  # type: Optional[List[Tuple[AnyStr, AnyStr, Any]]]
+    defined=None,  # type: Optional[List[AnyStr]]
     includeShelved=False,  # type: bool
 ):
     # type: (...) -> AlarmQueryResultImpl
@@ -299,7 +299,7 @@ def queryStatus(
 
 
 def shelve(path, timeoutSeconds=0, timeoutMinutes=15):
-    # type: (List[String], int, int) -> None
+    # type: (List[AnyStr], int, int) -> None
     """This function shelves the specified alarms for the specified
     amount of time.
 
@@ -323,7 +323,7 @@ def shelve(path, timeoutSeconds=0, timeoutMinutes=15):
 
 
 def unshelve(path):
-    # type: (List[String]) -> None
+    # type: (List[AnyStr]) -> None
     """Unshelves a list of alarms based on the source paths provided.
 
     Args:
