@@ -28,14 +28,15 @@ __all__ = [
 ]
 
 import __builtin__ as builtins
-
 from typing import List, Union
 
 from org.apache.commons.math3.exception import DimensionMismatchException
 
+Number = Union[float, int]
+
 
 def geometricMean(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Calculates the geometric mean.
 
     Geometric Mean is a type of average which indicates a typical value
@@ -59,7 +60,7 @@ def geometricMean(values):
 
 
 def kurtosis(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Calculates the kurtosis of a sequence of values.
 
     Kurtosis measures if data is peaked or flat relative to normal
@@ -88,7 +89,7 @@ def kurtosis(values):
 
 
 def max(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Given a sequence of values, returns the greatest value in the
     sequence, also known as the "max" value.
 
@@ -108,7 +109,7 @@ def max(values):
 
 
 def mean(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Given a sequence of values, calculates the arithmetic mean
     (average).
 
@@ -128,7 +129,7 @@ def mean(values):
 
 
 def meanDifference(values1, values2):
-    # type: (List[Union[float, int]], List[Union[float, int]]) -> float
+    # type: (List[Number], List[Number]) -> float
     """Given two sequences of values, calculates the mean of the signed
     difference between both sequences.
 
@@ -159,7 +160,7 @@ def meanDifference(values1, values2):
 
 
 def median(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Takes a sequence of values, and returns the median.
 
     The Median represents the middle value in a set of data.
@@ -180,7 +181,7 @@ def median(values):
 
 
 def min(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Given a Sequence of numerical values, returns the minimum value,
     also known as the "min" value.
 
@@ -200,7 +201,7 @@ def min(values):
 
 
 def mode(values):
-    # type: (List[Union[float, int]]) -> List[float]
+    # type: (List[Number]) -> List[float]
     """Given a sequence of values, returns the 'mode', or most frequent
     values.
 
@@ -221,7 +222,7 @@ def mode(values):
 
 
 def normalize(values):
-    # type: (List[Union[float, int]]) -> List[float]
+    # type: (List[Number]) -> List[float]
     """Given a sequence of values, normalizes the values.
 
     Normalizing data refers to adjusting values measured on different
@@ -248,7 +249,7 @@ def normalize(values):
 
 
 def percentile(values, percentile):
-    # type: (List[Union[float, int]], float) -> float
+    # type: (List[Number], float) -> float
     """Given a sequence of numerical values, estimates the percentile of
     input.
 
@@ -277,7 +278,7 @@ def percentile(values, percentile):
 
 
 def populationVariance(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Given a sequence of values, returns the Population Variance.
 
     Population variance calculates how values in a dataset are spread
@@ -299,7 +300,7 @@ def populationVariance(values):
 
 
 def product(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Given a sequence of values, calculates the product of the
     sequence: the result of multiplying of all values in the sequence
     together.
@@ -321,7 +322,7 @@ def product(values):
 
 
 def skewness(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Calculates the skewness given a sequence of values.
 
     Skewness is a measure of the degree of asymmetry of a distribution
@@ -346,7 +347,7 @@ def skewness(values):
 
 
 def standardDeviation(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Given a Sequence of numerical values, calculates the standard
     deviation.
 
@@ -370,7 +371,7 @@ def standardDeviation(values):
 
 
 def sum(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Given a sequence of values, calculates the sum of all values.
 
     The sum is the number returned by addition.
@@ -391,7 +392,7 @@ def sum(values):
 
 
 def sumDifference(values1, values2):
-    # type: (List[Union[float, int]], List[Union[float, int]]) -> float
+    # type: (List[Number], List[Number]) -> float
     """Given two sequences of values, calculates the sum of the signed
     difference between both sequences.
 
@@ -421,7 +422,7 @@ def sumDifference(values1, values2):
 
 
 def sumLog(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Given a sequence of values, calculates the sum of the natural
     logs.
 
@@ -442,7 +443,7 @@ def sumLog(values):
 
 
 def sumSquares(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Given a sequence of values, calculates the sum of the squares of
     all values.
 
@@ -465,7 +466,7 @@ def sumSquares(values):
 
 
 def variance(values):
-    # type: (List[Union[float, int]]) -> float
+    # type: (List[Number]) -> float
     """Given a sequence of values, calculates the variance of all
     values.
 
