@@ -25,12 +25,12 @@ from typing import Any, Dict, Optional, Union
 
 from com.inductiveautomation.factorypmi.application import FPMIWindow
 from com.inductiveautomation.factorypmi.application.script.builtin import NavUtilities
-from java.lang import String
+from dev.thecesrom.helper.types import AnyStr
 from java.util import EventObject
 
 
 def centerWindow(arg):
-    # type: (Union[String, FPMIWindow]) -> None
+    # type: (Union[AnyStr, FPMIWindow]) -> None
     """Given a window path, or a reference to a window itself, it will
     center the window.
 
@@ -56,7 +56,7 @@ def closeParentWindow(event):
 
 
 def closeWindow(arg):
-    # type: (Union[String, FPMIWindow]) -> None
+    # type: (Union[AnyStr, FPMIWindow]) -> None
     """Given a window path, or a reference to a window itself, it will
     close the window.
 
@@ -70,7 +70,7 @@ def closeWindow(arg):
 
 
 def desktop(handle="primary"):
-    # type: (Optional[String]) -> NavUtilities
+    # type: (Optional[AnyStr]) -> NavUtilities
     """Allows for invoking system.nav functions on a specific desktop.
 
     Args:
@@ -86,7 +86,7 @@ def desktop(handle="primary"):
 
 
 def getCurrentWindow():
-    # type: () -> String
+    # type: () -> AnyStr
     """Returns the path of the current "main screen" window, which is
     defined as the maximized window.
 
@@ -138,7 +138,7 @@ def goHome():
 
 
 def openWindow(path, params=None):
-    # type: (String, Optional[Dict[String, Any]]) -> FPMIWindow
+    # type: (AnyStr, Optional[Dict[AnyStr, Any]]) -> FPMIWindow
     """Opens the window with the given path.
 
     If the window is already open, brings it to the front. The optional
@@ -160,7 +160,7 @@ def openWindow(path, params=None):
 
 
 def openWindowInstance(path, params=None):
-    # type: (String, Optional[Dict[String, Any]]) -> FPMIWindow
+    # type: (AnyStr, Optional[Dict[AnyStr, Any]]) -> FPMIWindow
     """Operates exactly like system.nav.openWindow, except that if the
     named window is already open, then an additional instance of the
     window will be opened.
@@ -183,7 +183,7 @@ def openWindowInstance(path, params=None):
 
 
 def swapTo(path, params=None):
-    # type: (String, Optional[Dict[String, Any]]) -> FPMIWindow
+    # type: (AnyStr, Optional[Dict[AnyStr, Any]]) -> FPMIWindow
     """Performs a window swap from the current main screen window to the
     window specified.
 
@@ -208,9 +208,9 @@ def swapTo(path, params=None):
 
 
 def swapWindow(
-    arg,  # type: Union[String, EventObject]
-    swapToPath,  # type: String
-    params=None,  # type: Optional[Dict[String, Any]]
+    arg,  # type: Union[AnyStr, EventObject]
+    swapToPath,  # type: AnyStr
+    params=None,  # type: Optional[Dict[AnyStr, Any]]
 ):
     # type: (...) -> FPMIWindow
     """Performs a window swap.
