@@ -46,12 +46,12 @@ from com.inductiveautomation.ignition.common.user.schedule import (
     HolidayModel,
     ScheduleAdjustment,
 )
-from java.lang import String
+from dev.thecesrom.helper.types import AnyStr
 from java.util import Date, Locale
 
 
 def addCompositeSchedule(name, scheduleOne, scheduleTwo, description=None):
-    # type: (String, String, String, Optional[String]) -> UIResponse
+    # type: (AnyStr, AnyStr, AnyStr, Optional[AnyStr]) -> UIResponse
     """Allows two schedules to be combined into a composite schedule.
 
     Args:
@@ -84,7 +84,7 @@ def addHoliday(holiday):
 
 
 def addRole(userSource, role):
-    # type: (String, String) -> UIResponse
+    # type: (AnyStr, AnyStr) -> UIResponse
     """Allows a role to the specified user source.
 
     When altering the Gateway System User Source, the Allow User Admin
@@ -122,7 +122,7 @@ def addSchedule(schedule):
 
 
 def addUser(userSource, user):
-    # type: (String, PyUser) -> UIResponse
+    # type: (AnyStr, PyUser) -> UIResponse
     """Adds a new user to a user source.
 
     Used in combination with getNewUser to create new user.
@@ -143,7 +143,7 @@ def addUser(userSource, user):
 
 
 def createScheduleAdjustment(startDate, endDate, isAvailable, note):
-    # type: (Date, Date, bool, String) -> ScheduleAdjustment
+    # type: (Date, Date, bool, AnyStr) -> ScheduleAdjustment
     """Creates a schedule adjustment.
 
     Args:
@@ -160,7 +160,7 @@ def createScheduleAdjustment(startDate, endDate, isAvailable, note):
 
 
 def editHoliday(holidayName, holiday):
-    # type: (String, HolidayModel) -> UIResponse
+    # type: (AnyStr, HolidayModel) -> UIResponse
     """Allows a holiday to be edited.
 
     Args:
@@ -177,7 +177,7 @@ def editHoliday(holidayName, holiday):
 
 
 def editRole(userSource, oldName, newName):
-    # type: (String, String, String) -> UIResponse
+    # type: (AnyStr, AnyStr, AnyStr) -> UIResponse
     """Renames a role in the specified user source.
 
     When altering the Gateway System User Source, the Allow User Admin
@@ -199,7 +199,7 @@ def editRole(userSource, oldName, newName):
 
 
 def editSchedule(scheduleName, schedule):
-    # type: (String, AbstractScheduleModel) -> UIResponse
+    # type: (AnyStr, AbstractScheduleModel) -> UIResponse
     """Allows a schedule to be edited.
 
     Args:
@@ -218,7 +218,7 @@ def editSchedule(scheduleName, schedule):
 
 
 def editUser(userSource, user):
-    # type: (String, PyUser) -> UIResponse
+    # type: (AnyStr, PyUser) -> UIResponse
     """Alters a specific user in a user source, replacing the previous
     data with the new data passed in.
 
@@ -236,7 +236,7 @@ def editUser(userSource, user):
 
 
 def getHoliday(holidayName):
-    # type: (String) -> Optional[HolidayModel]
+    # type: (AnyStr) -> Optional[HolidayModel]
     """Returns a specific holiday.
 
     Args:
@@ -250,7 +250,7 @@ def getHoliday(holidayName):
 
 
 def getHolidayNames():
-    # type: () -> List[String]
+    # type: () -> List[AnyStr]
     """Returns a collection of strings of all holiday names.
 
     Returns:
@@ -271,7 +271,7 @@ def getHolidays():
 
 
 def getNewUser(userSource, username):
-    # type: (String, String) -> PyUser
+    # type: (AnyStr, AnyStr) -> PyUser
     """Creates a new user object.
 
     The user will not be added to the user source until addUser is
@@ -291,7 +291,7 @@ def getNewUser(userSource, username):
 
 
 def getRoles(userSource):
-    # type: (String) -> List[String]
+    # type: (AnyStr) -> List[AnyStr]
     """Returns a sequence of strings representing all of the roles
     configured in a specific user source.
 
@@ -306,7 +306,7 @@ def getRoles(userSource):
 
 
 def getSchedule(scheduleName):
-    # type: (String) -> Optional[AbstractScheduleModel]
+    # type: (AnyStr) -> Optional[AbstractScheduleModel]
     """Returns a specific schedule.
 
     Args:
@@ -326,7 +326,7 @@ def getSchedule(scheduleName):
 
 
 def getScheduleNames():
-    # type: () -> List[String]
+    # type: () -> List[AnyStr]
     """Returns a sequence of strings representing the names of all of
     the schedules available.
 
@@ -338,7 +338,7 @@ def getScheduleNames():
 
 
 def getScheduledUsers(userSource, date=Date()):
-    # type: (String, Optional[Union[Date, int]]) -> List[PyUser]
+    # type: (AnyStr, Optional[Union[Date, int]]) -> List[PyUser]
     """Returns a list of users that are scheduled on.
 
     If no users are scheduled, it will return an empty list.
@@ -373,7 +373,7 @@ def getSchedules():
 
 
 def getUser(userSource, username):
-    # type: (String, String) -> PyUser
+    # type: (AnyStr, AnyStr) -> PyUser
     """Looks up a specific user in a user source, by username.
 
     The full User object is returned except for the user's password.
@@ -411,7 +411,7 @@ def getUserSources():
 
 
 def getUsers(userSource):
-    # type: (String) -> List[PyUser]
+    # type: (AnyStr) -> List[PyUser]
     """Retrieves the list of users in a specific user source.
 
     The User objects that are returned contain all of the information
@@ -447,7 +447,7 @@ def isUserScheduled(user, date=None):
 
 
 def removeHoliday(holidayName):
-    # type: (String) -> UIResponse
+    # type: (AnyStr) -> UIResponse
     """Allows a holiday to be deleted.
 
     Args:
@@ -462,7 +462,7 @@ def removeHoliday(holidayName):
 
 
 def removeRole(userSource, role):
-    # type: (String, String) -> UIResponse
+    # type: (AnyStr, AnyStr) -> UIResponse
     """Removes a role from the specified user source.
 
     When altering the Gateway System User Source, the Allow User Admin
@@ -482,7 +482,7 @@ def removeRole(userSource, role):
 
 
 def removeSchedule(scheduleName):
-    # type: (String) -> UIResponse
+    # type: (AnyStr) -> UIResponse
     """Allows a schedule to be deleted.
 
     Note that schedules which are used in Composite Schedules can not be
@@ -501,7 +501,7 @@ def removeSchedule(scheduleName):
 
 
 def removeUser(userSource, username):
-    # type: (String, String) -> UIResponse
+    # type: (AnyStr, AnyStr) -> UIResponse
     """Removes a specific user from a user source based on username.
 
     Args:
