@@ -73,8 +73,9 @@ from com.inductiveautomation.ignition.common.script.builtin import (
     SystemUtilities,
 )
 from com.inductiveautomation.ignition.common.util import LoggerEx
+from dev.thecesrom.helper.types import AnyStr
 from java.awt import Toolkit
-from java.lang import String, Thread
+from java.lang import Thread
 from java.util import Date, Locale
 
 APPLET_FLAG = 16
@@ -88,12 +89,12 @@ WEBSTART_FLAG = 8
 
 
 def audit(
-    action=None,  # type: Optional[String]
-    actionValue=None,  # type: Optional[String]
-    auditProfile="",  # type: String
-    actor=None,  # type: Optional[String]
-    actorHost="localhost",  # type: String
-    originatingSystem=None,  # type: Optional[List[String]]
+    action=None,  # type: Optional[AnyStr]
+    actionValue=None,  # type: Optional[AnyStr]
+    auditProfile="",  # type: AnyStr
+    actor=None,  # type: Optional[AnyStr]
+    actorHost="localhost",  # type: AnyStr
+    originatingSystem=None,  # type: Optional[List[AnyStr]]
     eventTimestamp=None,  # type: Optional[Date]
     originatingContext=4,  # type: int
     statusCode=0,  # type: int
@@ -147,7 +148,7 @@ def beep():
 
 
 def execute(commands):
-    # type: (List[String]) -> None
+    # type: (List[AnyStr]) -> None
     """Executes the given commands via the operating system, in a
     separate process.
 
@@ -179,7 +180,7 @@ def exit(force=False):
 
 
 def getAvailableLocales():
-    # type: () -> List[String]
+    # type: () -> List[AnyStr]
     """Returns a collection of strings representing the Locales added
     to the Translation Manager, such as 'en' for English.
 
@@ -191,7 +192,7 @@ def getAvailableLocales():
 
 
 def getAvailableTerms():
-    # type: () -> List[String]
+    # type: () -> List[AnyStr]
     """Returns a collection of available terms defined in the
     translation system.
 
@@ -246,7 +247,7 @@ def getConnectionMode():
 
 
 def getEdition():
-    # type: () -> String
+    # type: () -> AnyStr
     """Returns the "edition" of the Vision Client - "standard",
     "limited", or "panel".
 
@@ -269,7 +270,7 @@ def getGatewayAddress():
 
 
 def getGatewayStatus(
-    gatewayAddress,  # type: String
+    gatewayAddress,  # type: AnyStr
     connectTimeoutMillis=None,  # type: Optional[int]
     socketTimeoutMillis=None,  # type: Optional[int]
     bypassCertValidation=True,  # type: bool
@@ -305,7 +306,7 @@ def getGatewayStatus(
 
 
 def getGlobals():
-    # type: () -> Dict[String, Any]
+    # type: () -> Dict[AnyStr, Any]
     """This method returns a dictionary that provides access to the
     legacy global namespace.
 
@@ -341,7 +342,7 @@ def getInactivitySeconds():
 
 
 def getLocale():
-    # type: () -> String
+    # type: () -> AnyStr
     """Returns the current string representing the user's Locale, such
     as 'en' for English.
 
@@ -352,7 +353,7 @@ def getLocale():
 
 
 def getLogger(name):
-    # type: (String) -> LoggerEx
+    # type: (AnyStr) -> LoggerEx
     """Returns a Logger object that can be used to log messages to the
     console.
 
@@ -381,7 +382,7 @@ def getModules():
 
 
 def getProjectName():
-    # type: () -> String
+    # type: () -> AnyStr
     """Returns the name of the project that is currently being run.
 
     Returns:
@@ -391,7 +392,7 @@ def getProjectName():
 
 
 def getProperty(propertyName):
-    # type: (String) -> Optional[unicode]
+    # type: (AnyStr) -> Optional[unicode]
     r"""Retrieves the value of a named system property.
 
     Some of the available properties are:
@@ -448,8 +449,8 @@ def getReadTimeout():
 
 
 def getSessionInfo(
-    usernameFilter=None,  # type: Optional[String]
-    projectFilter=None,  # type: Optional[String]
+    usernameFilter=None,  # type: Optional[AnyStr]
+    projectFilter=None,  # type: Optional[AnyStr]
 ):
     # type: (...) -> DatasetUtilities.PyDataSet
     """Returns a PyDataSet holding information about all of the open
@@ -501,7 +502,7 @@ def getVersion():
         The currently running Ignition version number, as a Version
         object.
     """
-    major, minor, rev = [int(i) for i in version.__version__.split(".")]
+    major, minor, rev = tuple(map(int, version.__version__.split(".")[:3]))
     build = int(version.__build__)
     return Version(major=major, minor=minor, rev=rev, build=build)
 
@@ -509,8 +510,8 @@ def getVersion():
 def invokeAsynchronous(
     function,  # type: Callable[..., Any]
     args=None,  # type: Optional[Iterable[Any]]
-    kwargs=None,  # type: Optional[Dict[String, Any]]
-    description=None,  # type: Optional[String]
+    kwargs=None,  # type: Optional[Dict[AnyStr, Any]]
+    description=None,  # type: Optional[AnyStr]
 ):
     # type: (...) -> Thread
     """Invokes (calls) the given Python function on a different thread.
@@ -570,7 +571,7 @@ def invokeLater(function, delay=0):
 
 
 def jsonDecode(jsonString):
-    # type: (String) -> Any
+    # type: (AnyStr) -> Any
     """Takes a JSON string and converts it into a Python object such as
     a list or a dictionary.
 
@@ -586,7 +587,7 @@ def jsonDecode(jsonString):
 
 
 def jsonEncode(pyObj, indentFactor=4):
-    # type: (Iterable[Any], int) -> String
+    # type: (Iterable[Any], int) -> AnyStr
     """Takes a Python object such as a list or dict and converts into a
     JSON string.
 
@@ -603,7 +604,7 @@ def jsonEncode(pyObj, indentFactor=4):
 
 
 def modifyTranslation(term, translation, locale="es_MX"):
-    # type: (String, String, String) -> None
+    # type: (AnyStr, AnyStr, AnyStr) -> None
     """This function allows you to add or modify a global translation.
 
     Args:
@@ -639,14 +640,14 @@ def playSoundClip(wav, volume=1.0, wait=False):
 
 
 def queryAuditLog(
-    auditProfileName=None,  # type: Optional[String]
+    auditProfileName=None,  # type: Optional[AnyStr]
     startDate=None,  # type: Optional[Date]
     endDate=None,  # type: Optional[Date]
-    actorFilter=None,  # type: Optional[String]
-    actionFilter=None,  # type: Optional[String]
-    targetFilter=None,  # type: Optional[String]
-    valueFilter=None,  # type: Optional[String]
-    systemFilter=None,  # type: Optional[String]
+    actorFilter=None,  # type: Optional[AnyStr]
+    actionFilter=None,  # type: Optional[AnyStr]
+    targetFilter=None,  # type: Optional[AnyStr]
+    valueFilter=None,  # type: Optional[AnyStr]
+    systemFilter=None,  # type: Optional[AnyStr]
     contextFilter=None,  # type: Optional[int]
 ):
     # type: (...) -> BasicDataset
@@ -694,10 +695,10 @@ def queryAuditLog(
 
 
 def retarget(
-    project,  # type: String
-    addresses=None,  # type: Optional[Union[String, List[String]]]
-    params=None,  # type: Optional[Dict[String, Any]]
-    windows=None,  # type: Optional[String]
+    project,  # type: AnyStr
+    addresses=None,  # type: Optional[Union[AnyStr, List[AnyStr]]]
+    params=None,  # type: Optional[Dict[AnyStr, Any]]
+    windows=None,  # type: Optional[AnyStr]
 ):
     # type: (...) -> None
     """This function allows you to programmatically 'retarget' the
@@ -742,17 +743,17 @@ def retarget(
 
 
 def sendMessage(
-    project,  # type: String
-    messageHandler,  # type: String
-    payload=None,  # type: Optional[Dict[String, Any]]
-    scope=None,  # type: Optional[String]
-    clientSessionId=None,  # type: Optional[String]
-    user=None,  # type: Optional[String]
-    hasRole=None,  # type: Optional[String]
-    hostName=None,  # type: Optional[String]
-    remoteServers=None,  # type: Optional[List[String]]
+    project,  # type: AnyStr
+    messageHandler,  # type: AnyStr
+    payload=None,  # type: Optional[Dict[AnyStr, Any]]
+    scope=None,  # type: Optional[AnyStr]
+    clientSessionId=None,  # type: Optional[AnyStr]
+    user=None,  # type: Optional[AnyStr]
+    hasRole=None,  # type: Optional[AnyStr]
+    hostName=None,  # type: Optional[AnyStr]
+    remoteServers=None,  # type: Optional[List[AnyStr]]
 ):
-    # type: (...) -> List[String]
+    # type: (...) -> List[AnyStr]
     """This function sends a message to clients running under the
     Gateway, or to a project within the Gateway itself.
 
@@ -807,12 +808,12 @@ def sendMessage(
 
 
 def sendRequest(
-    project,  # type: String
-    messageHandler,  # type: String
-    payload=None,  # type: Optional[Dict[String, Any]]
-    hostName=None,  # type: Optional[String]
-    remoteServer=None,  # type: Optional[String]
-    timeoutSec=None,  # type: Optional[String]
+    project,  # type: AnyStr
+    messageHandler,  # type: AnyStr
+    payload=None,  # type: Optional[Dict[AnyStr, Any]]
+    hostName=None,  # type: Optional[AnyStr]
+    remoteServer=None,  # type: Optional[AnyStr]
+    timeoutSec=None,  # type: Optional[AnyStr]
 ):
     # type: (...) -> Any
     """This function sends a message to the Gateway, working in a
@@ -857,11 +858,11 @@ def sendRequest(
 
 
 def sendRequestAsync(
-    project,  # type: String
-    messageHandler,  # type: String
-    payload=None,  # type: Optional[Dict[String, Any]]
-    hostName=None,  # type: Optional[String]
-    remoteServer=None,  # type: Optional[String]
+    project,  # type: AnyStr
+    messageHandler,  # type: AnyStr
+    payload=None,  # type: Optional[Dict[AnyStr, Any]]
+    hostName=None,  # type: Optional[AnyStr]
+    remoteServer=None,  # type: Optional[AnyStr]
     timeoutSec=None,  # type: Optional[int]
     onSuccess=None,  # type: Optional[Callable[..., Any]]
     onError=None,  # type: Optional[Callable[..., Any]]
@@ -947,7 +948,7 @@ def setConnectionMode(mode):
 
 
 def setLocale(locale):
-    # type: (Union[String, Locale]) -> None
+    # type: (Union[AnyStr, Locale]) -> None
     """Sets the user's current Locale.
 
     Any valid Java locale code (case-insensitive) can be used as a
@@ -965,7 +966,7 @@ def setLocale(locale):
 
 
 def setLoggingLevel(loggerName, loggerLevel):
-    # type: (String, String) -> None
+    # type: (AnyStr, AnyStr) -> None
     """Sets the logging level on the given logger.
 
     This can be a logger you create, or a logger already defined in the
@@ -1006,7 +1007,7 @@ def threadDump():
 
 
 def translate(term, locale="es_MX", strict=False):
-    # type: (String, Optional[String], Optional[bool]) -> String
+    # type: (AnyStr, Optional[AnyStr], Optional[bool]) -> AnyStr
     """This function allows you to retrieve the global translation of a
     term from the translation database using the current locale.
 
